@@ -1,3 +1,6 @@
+from reciprocalspaceship.algorithms.intensity import (
+    compute_intensity_from_structurefactor,
+)
 from reciprocalspaceship.algorithms.merge import merge
 from reciprocalspaceship.algorithms.scale_merged_intensities import (
     scale_merged_intensities,
