@@ -3,7 +3,7 @@ import numpy as np
 import pandas as pd
 from pandas.api.types import is_complex_dtype
 
-from reciprocalspaceship import dtypes
+from reciprocalspaceship import concat, dtypes
 from reciprocalspaceship.dataseries import DataSeries
 from reciprocalspaceship.decorators import (
     cellify,
@@ -11,6 +11,7 @@ from reciprocalspaceship.decorators import (
     range_indexed,
     spacegroupify,
 )
+from reciprocalspaceship.dtypes.base import MTZDtype
 from reciprocalspaceship.utils import (
     apply_to_hkl,
     bin_by_percentile,
@@ -315,7 +316,13 @@ class DataSet(pd.DataFrame):
         """
         return cls(gemmiMtz)
 
-    def to_gemmi(self, skip_problem_mtztypes=False):
+    def to_gemmi(
+        self,
+        skip_problem_mtztypes=False,
+        project_name="reciprocalspaceship",
+        crystal_name="reciprocalspaceship",
+        dataset_name="reciprocalspaceship",
+    ):
         """
         Creates gemmi.Mtz object from DataSet object.
 
@@ -331,6 +338,12 @@ class DataSet(pd.DataFrame):
         skip_problem_mtztypes : bool
             Whether to skip columns in DataSet that do not have specified
             MTZ datatypes
+        project_name : str
+            Project name to assign to MTZ file
+        crystal_name : str
+            Crystal name to assign to MTZ file
+        dataset_name : str
+            Dataset name to assign to MTZ file
 
         Returns
         -------
@@ -338,7 +351,9 @@ class DataSet(pd.DataFrame):
         """
         from reciprocalspaceship import io
 
-        return io.to_gemmi(self, skip_problem_mtztypes)
+        return io.to_gemmi(
+            self, skip_problem_mtztypes, project_name, crystal_name, dataset_name
+        )
 
     def to_pickle(self, path, *args, **kwargs):
         """
@@ -404,50 +419,6 @@ class DataSet(pd.DataFrame):
         """
         return from_structurefactor(self[sf_key])
 
-    def append(self, *args, check_isomorphous=True, **kwargs):
-        """
-        Append rows of `other` to the end of calling DataSet, returning
-        a new DataSet object. Any columns in `other` that are not present
-        in the calling DataSet are added as new columns.
-
-        For additional documentation on accepted arguments, see the
-        `Pandas DataFrame.append() API <https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.append.html>`_.
-
-        Parameters
-        ----------
-        check_isomorphous : bool
-            If True, the spacegroup and cell attributes of DataSets in `other`
-            will be compared to those of the calling DataSet to ensure
-            they are isomorphous.
-
-        Returns
-        -------
-        rs.DataSet
-
-        See Also
-        --------
-        concat : Concatenate ``rs`` objects
-        """
-        other = kwargs.get("other", args[0])
-        if check_isomorphous:
-            if isinstance(other, (list, tuple)):
-                for o in other:
-                    if isinstance(o, DataSet) and not self.is_isomorphous(o):
-                        raise ValueError("DataSet in `other` is not isomorphous")
-            else:
-                if isinstance(other, DataSet) and not self.is_isomorphous(other):
-                    raise ValueError("`other` DataSet is not isomorphous")
-        result = super().append(*args, **kwargs)
-
-        # If `ignore_index=True`, the _index_dtypes attribute should
-        # be reset.
-        if isinstance(result.index, pd.RangeIndex) and self._index_dtypes != {}:
-            result.__finalize__(self)
-            result._index_dtypes = {}
-            return result
-
-        return result.__finalize__(self)
-
     def merge(self, *args, check_isomorphous=True, **kwargs):
         """
         Merge DataSet or named DataSeries using a database-style join on
@@ -514,7 +485,14 @@ class DataSet(pd.DataFrame):
         result = super().join(*args, **kwargs)
         return result.__finalize__(self)
 
-    def write_mtz(self, mtzfile, skip_problem_mtztypes=False):
+    def write_mtz(
+        self,
+        mtzfile,
+        skip_problem_mtztypes=False,
+        project_name="reciprocalspaceship",
+        crystal_name="reciprocalspaceship",
+        dataset_name="reciprocalspaceship",
+    ):
         """
         Write DataSet to MTZ file.
 
@@ -532,10 +510,63 @@ class DataSet(pd.DataFrame):
         skip_problem_mtztypes : bool
             Whether to skip columns in DataSet that do not have specified
             MTZ datatypes
+        project_name : str
+            Project name to assign to MTZ file
+        crystal_name : str
+            Crystal name to assign to MTZ file
+        dataset_name : str
+            Dataset name to assign to MTZ file
         """
         from reciprocalspaceship import io
 
-        return io.write_mtz(self, mtzfile, skip_problem_mtztypes)
+        return io.write_mtz(
+            self,
+            mtzfile,
+            skip_problem_mtztypes,
+            project_name,
+            crystal_name,
+            dataset_name,
+        )
+
+    def select_mtzdtype(self, dtype):
+        """
+        Return subset of DataSet’s columns that are of the given dtype.
+
+        Parameters
+        ----------
+        dtype : str or instance of MTZDtype
+            Single-letter MTZ code, name, or MTZDtype instance to return
+
+        Returns
+        -------
+        DataSet
+            Subset of the DataSet with columns matching the requested dtype. If
+            no columns of the requested dtype are found, an empty DataSet is
+            returned.
+
+        Raises
+        ------
+        ValueError
+            If `dtype` is not a string nor a MTZDtype instance
+        """
+        if isinstance(dtype, MTZDtype):
+            return self[[k for k in self if isinstance(self.dtypes[k], type(dtype))]]
+        elif isinstance(dtype, str):
+            # One-letter code
+            if len(dtype) == 1:
+                return self[
+                    [
+                        k
+                        for k in self
+                        if hasattr(self[k].dtype, "mtztype")
+                        and self[k].dtype.mtztype == dtype
+                    ]
+                ]
+            else:
+                return self[[k for k in self if self[k].dtype.name == dtype]]
+        raise ValueError(
+            f"dtype must be a str or MTZDtype instance. Called with: {dtype}"
+        )
 
     def get_phase_keys(self):
         """
@@ -912,7 +943,7 @@ class DataSet(pd.DataFrame):
         column_mapping_minus = dict(zip(minus_labels, new_labels))
         dataset_plus.rename(columns=column_mapping_plus, inplace=True)
         dataset_minus.rename(columns=column_mapping_minus, inplace=True)
-        F = dataset_plus.append(dataset_minus)
+        F = concat([dataset_plus, dataset_minus])
         for label in new_labels:
             F[label] = F[label].from_friedel_dtype()
 
@@ -1205,19 +1236,16 @@ class DataSet(pd.DataFrame):
                 "This function is only  applicable for reflection data in the reciprocal ASU and anomalous data in a two-column (unstacked) format"
             )
 
-        p1 = DataSet(spacegroup=self.spacegroup, cell=self.cell)
-
-        # Get all symops, in ascending order by ISYM
+        # Number of symops, including Friedel operations
         groupops = self.spacegroup.operations()
-        allops = [op for op in groupops for op in (op, op.negated())]
+        n_symops = len(groupops) * 2
 
-        # Apply each symop and drop duplicates with higher ISYM
-        for isym, op in enumerate(allops, 1):
-            ds = self.copy()
-            ds["M/ISYM"] = isym
-            ds["M/ISYM"] = ds["M/ISYM"].astype("M/ISYM")
-            p1 = p1.append(ds.hkl_to_observed(m_isym="M/ISYM"))
-            p1.drop_duplicates(subset=["H", "K", "L"], inplace=True)
+        # Copy data n_symops times with all possible M/ISYM values
+        p1 = self.loc[self.index.repeat(n_symops)]
+        p1["M/ISYM"] = np.tile(range(1, n_symops + 1), reps=len(self))
+        p1["M/ISYM"] = p1["M/ISYM"].astype("M/ISYM")
+        p1 = p1.hkl_to_observed(m_isym="M/ISYM", inplace=True)
+        p1.drop_duplicates(subset=["H", "K", "L"], inplace=True)
 
         # Restrict to p1 ASU
         p1.spacegroup = gemmi.SpaceGroup(1)
@@ -1236,7 +1264,7 @@ class DataSet(pd.DataFrame):
         DataSet
         """
         friedel = self.apply_symop("-x,-y,-z")
-        return self.append(friedel)
+        return concat([self, friedel])
 
     @inplace
     def canonicalize_phases(self, inplace=False):
